( cd bin ; rm -rf zcat )
( cd bin ; ln -sf gzip zcat )
( cd bin ; rm -rf gunzip )
( cd bin ; ln -sf gzip gunzip )
( cd usr/bin ; rm -rf gzip )
( cd usr/bin ; ln -sf ../../bin/gzip gzip )
( cd usr/bin ; rm -rf zcat )
( cd usr/bin ; ln -sf ../../bin/zcat zcat )
( cd usr/bin ; rm -rf zcmp )
( cd usr/bin ; ln -sf zdiff zcmp )
( cd usr/bin ; rm -rf gunzip )
( cd usr/bin ; ln -sf ../../bin/gunzip gunzip )
( cd usr/bin ; rm -rf zegrep )
( cd usr/bin ; ln -sf zgrep zegrep )
( cd usr/bin ; rm -rf zfgrep )
( cd usr/bin ; ln -sf zgrep zfgrep )
